@@ -214,6 +214,7 @@ Rcpp::List rubin_rules_univ( Rcpp::NumericMatrix parsM , Rcpp::NumericMatrix par
 	double tmp2=0;
 	double tmp3=0;
 	double eps=1e-10;
+	double Nimp2 = Nimp ;
 	
 	for ( int pp = 0; pp < NP ; pp++){
 	tmp1=0;
@@ -227,9 +228,10 @@ Rcpp::List rubin_rules_univ( Rcpp::NumericMatrix parsM , Rcpp::NumericMatrix par
 	
 	pars[pp] = tmp1 / Nimp ;
 	pars_varWithin[pp] = tmp3 / Nimp ;   		
-	pars_varBetween[pp] = ( tmp2 - Nimp * pow( pars[pp] , 2.0) ) / (Nimp - 1+eps ) ; 
-	pars_se[pp] = sqrt( pars_varWithin[pp] + ( 1 + 1/Nimp) * pars_varBetween[pp] ) ;
-	pars_fmi[pp] = ( 1 + 1/Nimp) * pars_varBetween[pp] / pow(pars_se[pp] + eps,2.0) ;
+	pars_varBetween[pp] = ( tmp2 - Nimp * pow( pars[pp] , 2.0) ) / (Nimp - 1+eps ) ;
+	// ARb 2014-09-10:  added "1.0" instead of "1"
+	pars_se[pp] = sqrt( pars_varWithin[pp] + ( 1.0 + 1/Nimp2) * pars_varBetween[pp] ) ;
+	pars_fmi[pp] = ( 1.0 + 1/Nimp2) * pars_varBetween[pp] / pow(pars_se[pp] + eps,2.0) ;
 	  }
 
 return Rcpp::List::create( 
